@@ -7,15 +7,17 @@
 
 #pragma once
 
-#include <QAudioProbe>
+#include <QAudioDecoder>
+#include <QAudioSource>
+#include <QMediaPlayer>
+#include <QMediaRecorder>
 #include <QObject>
 #include <QTimer>
 #include <QVariant>
-#include <QAudioRecorder>
-#include <QMediaPlayer>
+
 #include <QDebug>
 
-class AudioProber : public QAudioProbe
+class AudioProber : public QAudioDecoder
 {
     Q_OBJECT
     Q_PROPERTY(QVariantList volumesList READ volumesList NOTIFY volumesListChanged)
@@ -24,10 +26,10 @@ class AudioProber : public QAudioProbe
 
 public:
     AudioProber(QObject *parent = nullptr);
-    AudioProber(QObject *parent, QAudioRecorder *source);
+    AudioProber(QObject *parent, QMediaRecorder *source);
     AudioProber(QObject *parent, QMediaPlayer *source);
 
-    void process(QAudioBuffer buffer);
+    void process();
     void processVolumeBar();
 
     QVariantList volumesList() const;
@@ -39,9 +41,11 @@ public:
 
     void clearVolumesList();
 
+    void start();
+
 private:
-    void handleRecorderState(QAudioRecorder::State state);
-    void handlePlayerState(QMediaPlayer::State state);
+    void handleRecorderState(QMediaRecorder::RecorderState state);
+    void handlePlayerState(QMediaPlayer::PlaybackState state);
     
     int m_audioSum = 0;  //
     int m_audioLen = 0; // used for calculating the value of one volume bar from many
@@ -51,8 +55,10 @@ private:
     QVariantList m_volumesList;
 
     QTimer *volumeBarTimer;
-    QAudioRecorder *m_recorderSource;
+    QMediaRecorder *m_recorderSource;
     QMediaPlayer *m_playerSource;
+    QAudioSource *m_audioSource;
+    QIODevice *m_audioIODevice;
     
 Q_SIGNALS:
     void volumesListAdded(int volume);
