@@ -8,12 +8,10 @@
 
 #include <QObject>
 #include <QString>
-#include <QMultimedia>
 #include <QCoreApplication>
+#include <QSettings>
 #include <QQuickItem>
 
-#include <audiorecorder.h>
-
 class SettingsModel : public QObject
 {
     Q_OBJECT
@@ -59,8 +57,6 @@ public:
     int audioQuality() const;
     void setAudioQuality(int audioQuality);
 
-    Q_INVOKABLE void setBlur(QQuickItem *item, bool blur);
-
 private:
     explicit SettingsModel(QObject *parent = nullptr);
     ~SettingsModel();
